package com.dj.action.sys;

import org.apache.log4j.Logger;
import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;
import org.springframework.beans.factory.annotation.Autowired;

import com.dj.action.base.BaseAction;
import com.dj.pageModel.base.Json;
import com.dj.pageModel.sys.Area;
import com.dj.service.sys.AreaServiceI;
import com.dj.util.base.ExceptionUtil;
import com.opensymphony.xwork2.ModelDriven;

/**
 * 区域ACTION
 * 
 * @author lili
 * 
 */
@Action(value = "area", results = { @Result(name = "area", location = "/general/admin/area.jsp"), @Result(name = "areaAdd", location = "/general/admin/areaAdd.jsp"), @Result(name = "areaEdit", location = "/general/admin/areaEdit.jsp") })
public class AreaAction extends BaseAction implements ModelDriven<Area> {

	private static final long serialVersionUID = 1L;

	private static final Logger logger = Logger.getLogger(AreaAction.class);

	private AreaServiceI areaService;

	public AreaServiceI getAreaService() {
		return areaService;
	}

	@Autowired
	public void setAreaService(AreaServiceI areaService) {
		this.areaService = areaService;
	}

	private Area area = new Area();

	public Area getModel() {
		return area;
	}

	/**
	 * 动态获取区域树（当展开下级时才会加载下级区域）
	 */
	public void doNotNeedSession_tree() {
		super.writeJson(areaService.tree(area, false));
	}
	
	/**
	 * 一次性获取全部区域树
	 */
	public void doNotNeedSession_treeRecursive() {
		super.writeJson(areaService.tree(area, true));
	}

	public String area() {
		return "area";
	}

	/**
	 * 获得区域treegrid
	 */
	public void treegrid() {
		super.writeJson(areaService.treegrid(area));
	}

	/**
	 * 删除一个区域
	 */
	public void delete() {
		Json j = new Json();
		try {
			areaService.delete(area);
			j.setSuccess(true);
			j.setMsg("删除成功！");
			j.setObj(area.getCid());
		} catch (Exception e) {
			logger.error(ExceptionUtil.getExceptionMessage(e));
			j.setMsg("删除失败！区域已使用!");
		}
		super.writeJson(j);
	}

	public String areaAdd() {
		return "areaAdd";
	}

	public void add() {
		Json j = new Json();
		try {
			areaService.add(area);
			j.setSuccess(true);
			j.setMsg("添加成功！");
		} catch (Exception e) {
			logger.error(ExceptionUtil.getExceptionMessage(e));
			j.setMsg("添加失败！");
		}
		super.writeJson(j);
	}

	public String areaEdit() {
		return "areaEdit";
	}

	/**
	 * 编辑区域
	 */
	public void edit() {
		Json j = new Json();
		try {
			areaService.edit(area);
			j.setSuccess(true);
			j.setMsg("编辑成功!");
		} catch (Exception e) {
			logger.error(ExceptionUtil.getExceptionMessage(e));
			j.setMsg("编辑失败！");
		}
		writeJson(j);
	}

}
