package com.dj.service.sys.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.util.UUID;

import org.apache.struts2.ServletActionContext;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import com.dj.comparator.MineareaComparator;
import com.dj.dao.base.BaseDaoI;
import com.dj.model.sys.Tminearea;
import com.dj.pageModel.base.TreeNode;
import com.dj.pageModel.sys.Minearea;
import com.dj.service.base.impl.BaseServiceImpl;
import com.dj.service.sys.MineareaServiceI;
import com.dj.util.base.ResourceUtil;

import com.dj.pageModel.base.SessionInfo;

//引入session


@Service("mineareaService")
public class MineareaServiceImpl extends BaseServiceImpl implements MineareaServiceI {

	private BaseDaoI<Tminearea> mineareaDao;

	public BaseDaoI<Tminearea> getMineareaDao() {
		return mineareaDao;
	}

	@Autowired
	public void setMineareaDao(BaseDaoI<Tminearea> mineareaDao) {
		this.mineareaDao = mineareaDao;
	}

	@Transactional(readOnly = true, propagation = Propagation.SUPPORTS)
	public List<Minearea> findAll() {
		List<Minearea> ld = new ArrayList<Minearea>();
		String hql = "from Tminearea t order by t.cseq";
		List<Tminearea> ltd = mineareaDao.find(hql);
		for (Tminearea td : ltd) {
			Minearea d = new Minearea();
			d.setCid(td.getCid());
			d.setCname(td.getCname());
			d.setCiconcls(td.getCiconcls());
			if(td.getTminearea()!=null){
				d.setPid(td.getTminearea().getCid());
			}
			ld.add(d);
		}
		return ld;
	}

	@Transactional(readOnly = true, propagation = Propagation.SUPPORTS)
	public List<TreeNode> tree(Minearea minearea, Boolean b) {
		
		SessionInfo sessionInfo = (SessionInfo) ServletActionContext.getRequest().getSession().getAttribute(ResourceUtil.getSessionInfoName());
		//得到矿区
		String mineareacode = sessionInfo.getMineareacode();
		//得到矿区
		
		
		List<Object> param = new ArrayList<Object>();
		String hql = "";
		
		if("0".equals(mineareacode))
		{
			hql = "from Tminearea t where t.tminearea is null  order by t.cseq";
		}
		else
		{
			hql = "from Tminearea t where t.cid = ? order by t.cseq";
			param.add(mineareacode);
		}
		
		if (minearea != null && minearea.getId() != null && !minearea.getId().trim().equals("")) {
			hql = "from Tminearea t where t.tminearea.cid = ?  order by t.cseq";
			param.add(minearea.getId());
		}
		List<Tminearea> l = mineareaDao.find(hql, param);
		List<TreeNode> tree = new ArrayList<TreeNode>();
		for (Tminearea t : l) {
			tree.add(this.tree(t, b));
		}
		return tree;
	}

	//根据不同权限，得到数据不同
	private TreeNode tree(Tminearea t, boolean recursive) {
		
		TreeNode node = new TreeNode();
		node.setId(t.getCid());
		node.setText(t.getCname());
		if (t.getCiconcls() != null) {
			node.setIconCls(t.getCiconcls());
		} else {
			node.setIconCls("");
		}
		if (t.getTmineareas() != null && t.getTmineareas().size() > 0) {
			node.setState("closed");
			if (recursive) {// 递归查询子节点
				List<Tminearea> l = new ArrayList<Tminearea>(t.getTmineareas());
				Collections.sort(l, new MineareaComparator());// 排序
				List<TreeNode> children = new ArrayList<TreeNode>();
				for (Tminearea r : l) {
					TreeNode tn = tree(r, true);
					children.add(tn);
				}
				node.setChildren(children);
				node.setState("open");
			}
		}
		return node;
	}

	@Transactional(readOnly = true, propagation = Propagation.SUPPORTS)
	public List<Minearea> treegrid(Minearea minearea) {
		List<Tminearea> l;
		if (minearea != null && minearea.getId() != null) {
			l = mineareaDao.find("from Tminearea t where t.tminearea.cid = ? order by t.cseq", new Object[] { minearea.getId() });
		} else {
			l = mineareaDao.find("from Tminearea t where t.tminearea is null order by t.cseq");
		}
		return changeModel(l);
	}

	private List<Minearea> changeModel(List<Tminearea> Tmineareas) {
		List<Minearea> l = new ArrayList<Minearea>();
		if (Tmineareas != null && Tmineareas.size() > 0) {
			for (Tminearea t : Tmineareas) {
				Minearea m = new Minearea();
				BeanUtils.copyProperties(t, m);
				if (t.getTminearea() != null) {
					m.setPid(t.getTminearea().getCid());
					m.setPname(t.getTminearea().getCname());
				}
				if (countChildren(t.getCid()) > 0) {
					m.setState("closed");
				}
				if (t.getCiconcls() == null) {
					m.setIconCls("");
				} else {
					m.setIconCls(t.getCiconcls());
				}
				l.add(m);
			}
		}
		return l;
	}

	/**
	 * 统计有多少子节点
	 */
	private Long countChildren(String pid) {
		return mineareaDao.count("select count(*) from Tminearea t where t.tminearea.cid = ?", new Object[] { pid });
	}

	public void delete(Minearea minearea) {
		del(minearea.getCid());
	}

	private void del(String cid) {
		Tminearea t = mineareaDao.get(Tminearea.class, cid);
		if (t != null) {
			Set<Tminearea> mineareas = t.getTmineareas();
			if (mineareas != null && !mineareas.isEmpty()) {
				// 说明当前菜单下面还有子菜单
				for (Tminearea tminearea : mineareas) {
					del(tminearea.getCid());
				}
			}
			mineareaDao.delete(t);
		}
	}

	public void add(Minearea minearea) {
		Tminearea t = new Tminearea();
		BeanUtils.copyProperties(minearea, t);
		t.setCid(UUID.randomUUID().toString());
		if (minearea.getPid() != null) {
			t.setTminearea(mineareaDao.get(Tminearea.class, minearea.getPid()));
		}
		if (minearea.getIconCls() != null) {
			t.setCiconcls(minearea.getIconCls());
		}
		mineareaDao.save(t);
	}

	public void edit(Minearea minearea) {
		Tminearea t = mineareaDao.get(Tminearea.class, minearea.getCid());
		BeanUtils.copyProperties(minearea, t);
		if (minearea.getIconCls() != null) {
			t.setCiconcls(minearea.getIconCls());
		}
		if (minearea.getPid() != null && !minearea.getPid().equals(minearea.getCid())) {
			Tminearea pt = mineareaDao.get(Tminearea.class, minearea.getPid());
			if (pt != null) {
				if (isDown(t, pt)) {// 要将当前节点修改到当前节点的子节点中
					Set<Tminearea> tmineareas = t.getTmineareas();// 当前要修改的节点的所有下级节点
					if (tmineareas != null && tmineareas.size() > 0) {
						for (Tminearea tminearea : tmineareas) {
							if (tminearea != null) {
								tminearea.setTminearea(null);
							}
						}
					}
				}
				t.setTminearea(pt);
			}

		}
	}

	/**
	 * 判断是否是将当前节点修改到当前节点的子节点
	 * 
	 * @param t
	 * @param pt
	 * @return
	 */
	private boolean isDown(Tminearea t, Tminearea pt) {
		if (pt.getTminearea() != null) {
			if (pt.getTminearea().getCid().equals(t.getCid())) {
				return true;
			} else {
				return isDown(t, pt.getTminearea());
			}
		}
		return false;
	}

}
