package com.dj.service.sys.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.dj.dao.base.BaseDaoI;

import com.dj.model.sys.Tminearea;
import com.dj.model.sys.Tstation;
import com.dj.pageModel.base.DataGrid;
import com.dj.pageModel.sys.Station;
import com.dj.service.base.impl.BaseServiceImpl;

import com.dj.service.sys.StationServiceI;


@Service("stationService")
public class StationServiceImpl extends BaseServiceImpl implements StationServiceI {

	private BaseDaoI<Tstation> stationDao;
	private BaseDaoI<Tminearea> mineareaDao;

	public BaseDaoI<Tstation> getStationDao() {
		return stationDao;
	}

	@Autowired
	public void setStationDao(BaseDaoI<Tstation> stationDao) {
		this.stationDao = stationDao;
	}
	
	public BaseDaoI<Tminearea> getMineareaDao() {
		return mineareaDao;
	}	
	
	@Autowired
	public void setMineareaDao(BaseDaoI<Tminearea> mineareaDao) {
		this.mineareaDao = mineareaDao;
	}


	@Transactional(readOnly = true, propagation = Propagation.SUPPORTS)
	public DataGrid datagrid(Station station) {
		DataGrid j = new DataGrid();
		j.setRows(changeModel(find(station)));
		j.setTotal(total(station));
		return j;
	}

	private List<Station> changeModel(List<Tstation> tstations) {
		List<Station> stations = new ArrayList<Station>();
		if (tstations != null && tstations.size() > 0) {
			for (Tstation tb : tstations) {
				Station b = new Station();
				//BeanUtils.copyProperties(tb, b);
				b.setCid(tb.getCid());
				b.setCname(tb.getCname());
				b.setCaddr(tb.getCaddr());
				b.setCtype(tb.getCtype());
				b.setCxpos(tb.getCxpos());
				b.setCypos(tb.getCypos());
				b.setCzpos(tb.getCzpos());
				b.setCremark(tb.getCremark());
			    b.setCdwm(tb.getCdwm());
			    b.setCsenid(tb.getCsenid());
			    b.setComd(tb.getComd());
			    b.setClayer(tb.getClayer());
			    b.setCip(tb.getCip());
				
			//	System.out.println(tb.getTminearea().getCid());
				
				b.setMineareacode(tb.getTminearea().getCid());
				b.setMineareaname(tb.getTminearea().getCname());
			
				stations.add(b);
			}
		}
		return stations;
	}

	//
	private List<Tstation> find(Station station) {
		//String hql = "select new Tstation(t.cid,t.cname,t.caddr,t.ctype,t.cxpos,t.cypos,t.czpos,t.cremark) from Tstation t where 1=1 ";
		String hql = "from Tstation t where 1=1";

		List<Object> values = new ArrayList<Object>();
		hql = addWhere(station, hql, values);

		if (station.getSort() != null && station.getOrder() != null) {
			hql += " order by " + station.getSort() + " " + station.getOrder();
		}
		return stationDao.find(hql, values, station.getPage(), station.getRows());
	}

	private Long total(Station station) {
		String hql = "select count(*) from Tstation t where 1=1 ";
		List<Object> values = new ArrayList<Object>();
		hql = addWhere(station, hql, values);
		return stationDao.count(hql, values);
	}

	private String addWhere(Station station, String hql, List<Object> values) {
		return hql;
	}

	public void delete(String ids) {
		if (ids != null) {
			for (String id : ids.split(",")) {
				Tstation t = stationDao.get(Tstation.class, id);
				if (t != null) {
					stationDao.delete(t);
				}
			}
		}
	}

	public void add(Station station) {
		
		Tstation t = new Tstation();
		BeanUtils.copyProperties(station, t);
		t.setCid(UUID.randomUUID().toString());
		t.setTminearea(mineareaDao.get(Tminearea.class, station.getMineareacode()));
		stationDao.save(t);
	}



	public void update(Station station) {
		Tstation t = stationDao.get(Tstation.class, station.getCid());
		if (t != null) {
			t.setCname(station.getCname());
			t.setCaddr(station.getCaddr());
			t.setCtype(station.getCtype());
			t.setCxpos(station.getCxpos());
			t.setCypos(station.getCypos());
			t.setCzpos(station.getCzpos());
			t.setCremark(station.getCremark());
			t.setCdwm(station.getCdwm());
			t.setCsenid(station.getCsenid());
			t.setComd(station.getComd());
			t.setClayer(station.getClayer());
			t.setCip(station.getCip());
		    t.setTminearea(mineareaDao.get(Tminearea.class, station.getMineareacode()));
			
			

		}
	}

}
